@@ -1,4 +1,6 @@
 from .carts import BigCommerceCartsAPI
+from .categories import BigCommerceCategoriesAPI
+from .customer_groups import BigCommerceCustomerGroupsAPI
 from .customers import BigCommerceCustomersAPI
 from .orders import BigCommerceOrdersAPI
 from .product_variants import BigCommerceProductVariantsAPI
