@@ -10,26 +10,43 @@ class BigCommerceCustomersAPI:
     def __init__(self, store_hash: str, access_token: str):
         self._v3_client = BigCommerceV3APIClient(store_hash, access_token)
 
-    def all(self, *, id_in: Iterable[int] = None, include_formfields: bool = False) -> Iterator[dict]:
+    def all(self, *, id_in: Iterable[int] = None, include_formfields: bool = False,
+            include_storecredit: bool = False) -> Iterator[dict]:
         """Return an iterator for all customers"""
         url_parts = urlparse('/customers')
 
         query_dict = {}
+
         if id_in is not None:
             query_dict['id:in'] = ','.join(map(str, id_in))
+
+        include = []
+        if include_storecredit:
+            include.append('storecredit')
         if include_formfields:
-            query_dict['include'] = 'formfields'
+            include.append('formfields')
+        if include:
+            query_dict['include'] = ','.join(include)
+
         url_parts = url_parts._replace(query=urlencode(query_dict))
 
         return self._v3_client.paginated_request('GET', urlunparse(url_parts))
 
-    def get(self, customer_id: int, *, include_formfields: bool = False) -> dict:
+    def get(self, customer_id: int, *, include_formfields: bool = False,
+            include_storecredit: bool = False) -> dict:
         """Get a specific customer by its ID"""
         url_parts = urlparse('/customers')
 
         query_dict = {'id:in': customer_id}
+
+        include = []
+        if include_storecredit:
+            include.append('storecredit')
         if include_formfields:
-            query_dict['include'] = 'formfields'
+            include.append('formfields')
+        if include:
+            query_dict['include'] = ','.join(include)
+
         url_parts = url_parts._replace(query=urlencode(query_dict))
 
         try:
