@@ -60,3 +60,13 @@ class BigCommerceProductsAPI:
     def delete(self, product_id: int) -> dict:
         """Delete a specific product by its ID"""
         return self._v3_client.request('DELETE', f'/catalog/products/{product_id}')
+
+    def get_pricing(self, items: list[dict], *, channel_id: int = 1, currency_code: str = 'USD',
+                    customer_group_id: int = 0) -> Iterator[dict]:
+        """Return an iterator for batch product pricing"""
+        return self._v3_client.request('POST', '/pricing/products', json={
+            'channel_id': channel_id,
+            'currency_code': currency_code,
+            'customer_group_id': customer_group_id,
+            'items': list(items),
+        })
